@@ -1,5 +1,3 @@
-//! Simple HTTP client
-
 use crate::io::{decode_response, encode_request};
 use crate::model::{
     HeaderName, HeaderValue, InvalidHeader, Method, Request, Response, Status, Url,
@@ -13,10 +11,9 @@ use native_tls::TlsConnector;
 use rustls_crate::{ClientConfig, ClientConnection, RootCertStore, ServerName, StreamOwned};
 #[cfg(feature = "rustls")]
 use rustls_native_certs::load_native_certs;
-use std::convert::TryFrom;
 use std::io::{BufReader, BufWriter, Error, ErrorKind, Result};
 use std::net::{SocketAddr, TcpStream};
-#[cfg(any(feature = "native-tls", feature = "rustls"))]
+#[cfg(feature = "rustls")]
 use std::sync::Arc;
 use std::time::Duration;
 
@@ -51,7 +48,7 @@ lazy_static! {
     };
 }
 
-/// A simple HTTP client.
+/// An HTTP client.
 ///
 /// It aims at following the basic concepts of the [Web Fetch standard](https://fetch.spec.whatwg.org/) without the bits specific to web browsers (context, CORS...).
 ///
@@ -86,7 +83,7 @@ impl Client {
         Self::default()
     }
 
-    /// Sets the global timout value (applies to both read, write and connection).
+    /// Sets the global timeout value (applies to both read, write and connection).
     #[inline]
     pub fn set_global_timeout(&mut self, timeout: Duration) {
         self.timeout = Some(timeout);
@@ -133,8 +130,7 @@ impl Client {
                 let location = location.to_str().map_err(invalid_data_error)?;
                 let new_url = request.url().join(location).map_err(|e| {
                     invalid_data_error(format!(
-                        "Invalid URL in Location header raising error {}: {}",
-                        e, location
+                        "Invalid URL in Location header raising error {e}: {location}"
                     ))
                 })?;
                 let mut request_builder = Request::builder(new_method, new_url);
