@@ -4,7 +4,6 @@ use crate::model::{
 };
 use crate::utils::invalid_data_error;
 use std::cmp::min;
-use std::convert::{TryFrom, TryInto};
 use std::io::{BufRead, Error, ErrorKind, Read, Result};
 use std::str;
 use std::str::FromStr;
@@ -48,25 +47,24 @@ pub fn decode_request_headers(
         }
     }) {
         let host = str::from_utf8(host)
-            .map_err(|e| invalid_data_error(format!("Invalid host header value: {}", e)))?;
+            .map_err(|e| invalid_data_error(format!("Invalid host header value: {e}")))?;
         let base_url = Url::parse(&if is_connection_secure {
-            format!("https://{}", host)
+            format!("https://{host}")
         } else {
-            format!("http://{}", host)
+            format!("http://{host}")
         })
-        .map_err(|e| invalid_data_error(format!("Invalid host header value '{}': {}", host, e)))?;
+        .map_err(|e| invalid_data_error(format!("Invalid host header value '{host}': {e}")))?;
         if path == "*" {
             base_url
         } else {
-            base_url.join(path).map_err(|e| {
-                invalid_data_error(format!("Invalid request path '{}': {}", path, e))
-            })?
+            base_url
+                .join(path)
+                .map_err(|e| invalid_data_error(format!("Invalid request path '{path}': {e}")))?
         }
     } else {
         Url::parse(path).map_err(|e| {
             invalid_data_error(format!(
-                "No host header in HTTP request and not absolute path '{}': {}",
-                path, e
+                "No host header in HTTP request and not absolute path '{path}': {e}"
             ))
         })?
     };
@@ -203,8 +201,7 @@ fn decode_body(headers: &Headers, reader: impl BufRead + 'static) -> Result<Body
             })
         } else {
             return Err(invalid_data_error(format!(
-                "Transfer-Encoding: {} is not supported",
-                transfer_encoding
+                "Transfer-Encoding: {transfer_encoding} is not supported"
             )));
         }
     } else {
@@ -261,11 +258,11 @@ impl<R: BufRead> Read for ChunkedDecoder<R> {
                 httparse::parse_chunk_size(&self.buffer)
             {
                 if read != self.buffer.len() {
-                    return Err(invalid_data_error("Chuncked header containing a line jump"));
+                    return Err(invalid_data_error("Chunked header containing a line jump"));
                 }
                 chunk_size.try_into().map_err(invalid_data_error)?
             } else {
-                return Err(invalid_data_error("Invalid chuncked header"));
+                return Err(invalid_data_error("Invalid chunked header"));
             };
 
             if self.chunk_size == 0 {
