@@ -1,7 +1,6 @@
 use std::borrow::{Borrow, Cow};
 use std::collections::btree_map::Entry;
 use std::collections::BTreeMap;
-use std::convert::{TryFrom, TryInto};
 use std::error::Error;
 use std::fmt;
 use std::fmt::Debug;
@@ -243,7 +242,7 @@ impl FromStr for HeaderName {
 
     #[inline]
     fn from_str(name: &str) -> Result<Self, InvalidHeader> {
-        name.to_owned().try_into()
+        Self::try_from(name)
     }
 }
 
@@ -252,7 +251,7 @@ impl TryFrom<&str> for HeaderName {
 
     #[inline]
     fn try_from(value: &str) -> Result<Self, InvalidHeader> {
-        value.to_owned().try_into()
+        Self::try_from(value.to_owned())
     }
 }
 
@@ -288,6 +287,24 @@ impl fmt::Display for HeaderName {
     }
 }
 
+pub trait IntoHeaderName {
+    fn try_into(self) -> Result<HeaderName, InvalidHeader>;
+}
+
+impl IntoHeaderName for HeaderName {
+    #[inline]
+    fn try_into(self) -> Result<HeaderName, InvalidHeader> {
+        Ok(self)
+    }
+}
+
+impl<T: TryInto<HeaderName, Error = InvalidHeader>> IntoHeaderName for T {
+    #[inline]
+    fn try_into(self) -> Result<HeaderName, InvalidHeader> {
+        self.try_into()
+    }
+}
+
 /// A [header/field value](https://httpwg.org/http-core/draft-ietf-httpbis-semantics-latest.html#fields.values).
 ///
 /// ```
@@ -339,7 +356,7 @@ impl FromStr for HeaderValue {
 
     #[inline]
     fn from_str(value: &str) -> Result<Self, InvalidHeader> {
-        value.to_owned().try_into()
+        Self::try_from(value)
     }
 }
 
@@ -348,7 +365,7 @@ impl TryFrom<&str> for HeaderValue {
 
     #[inline]
     fn try_from(value: &str) -> Result<Self, InvalidHeader> {
-        value.to_owned().try_into()
+        Self::try_from(value.to_owned())
     }
 }
 
@@ -357,7 +374,7 @@ impl TryFrom<String> for HeaderValue {
 
     #[inline]
     fn try_from(value: String) -> Result<Self, InvalidHeader> {
-        value.into_bytes().try_into()
+        Self::try_from(value.into_bytes())
     }
 }
 
@@ -503,8 +520,7 @@ impl fmt::Display for InvalidHeader {
             InvalidHeaderAlt::EmptyName => f.write_str("header names should not be empty"),
             InvalidHeaderAlt::InvalidNameChar { name, invalid_char } => write!(
                 f,
-                "The character '{}' is not valid inside of header name '{}'",
-                invalid_char, name
+                "The character '{invalid_char}' is not valid inside of header name '{name}'"
             ),
             InvalidHeaderAlt::InvalidValueByte {
                 value,
